@@ -4,10 +4,10 @@ import logging
 import re
 from typing import Dict, List, Optional
 
-from box.box import Box
 import jmespath
 import jwt
 import requests
+from box.box import Box
 
 from tavern._core import exceptions
 from tavern._core.dict_util import check_keys_match_recursive, recurse_access_key
@@ -34,26 +34,38 @@ def check_exception_raised(
     module = importlib.import_module(module_name)
     exception = getattr(module, exception_name)
 
-    if "title" in dumped:
-        assert dumped["title"] == exception.error_title
-    elif "error" in dumped:
-        assert dumped["error"] == exception.error_title
+    for possible_title in ["title", "error"]:
+        if possible_title in dumped:
+            try:
+                assert dumped[possible_title] == exception.error_title  # noqa
+            except AssertionError as e:
+                raise exceptions.UnexpectedExceptionError(
+                    "Incorrect title of exception"
+                ) from e
 
     actual_description = dumped.get("description", dumped.get("error_description"))
     expected_description = getattr(
-        exception, "error_description", getattr(exception, "description")
+        exception, "error_description", exception.description
     )
 
     try:
-        assert actual_description == expected_description
-    except AssertionError:
+        assert actual_description == expected_description  # noqa
+    except AssertionError as e:
         # If it has a format, ignore this error. Would be annoying to say how to
         # format things in the validator, especially if it's a set/dict which is
         # unordered
+        # TODO: improve logic? Use a regex like '{.+?}' instead?
         if not any(i in expected_description for i in "{}"):
-            raise
+            raise exceptions.UnexpectedExceptionError(
+                "exception description did not match"
+            ) from e
 
-    assert response.status_code == int(exception.status.split()[0])
+    try:
+        assert response.status_code == int(exception.status.split()[0])  # noqa
+    except AssertionError as e:
+        raise exceptions.UnexpectedExceptionError(
+            "exception status code did not match"
+        ) from e
 
 
 def validate_jwt(response, jwt_key, **kwargs) -> Dict[str, Box]:
@@ -205,7 +217,7 @@ def check_jmespath_match(parsed_response, query: str, expected: Optional[str] =
     if expected is not None:
         # Reuse dict util helper as it should behave the same
         check_keys_match_recursive(expected, actual, [], True)
-    elif not actual and not (actual == expected):  # pylint: disable=superfluous-parens
+    elif not actual and not (actual == expected):
         # This can return an empty list, but it might be what we expect. if not,
         # raise an exception
         raise exceptions.JMESError(msg)
